@@ -1,4 +1,5 @@
 from copy import copy
+from operator import xor
 from collections import OrderedDict
 from inspect import getmembers, ismethod
 
@@ -19,7 +20,7 @@ class Object(object):
         self.parent = None
         self.value = value
 
-        self.traits = []
+        self.traits = {}
         self.behaviors = {}
 
         self.binding = None
@@ -36,7 +37,14 @@ class Object(object):
         self.attrs.update(((v.name, v) for k, v in getmembers(self, ismethod) if getattr(v, "method", False) and k in keys))
 
     def __hash__(self):
-        return hash(self.value)
+        return (
+            reduce(xor, map(hash, self.attrs.keys()), 0) ^
+            hash(self.parent) ^
+            hash(self.value) ^
+            reduce(xor, map(hash, self.traits.keys()), 0) ^
+            reduce(xor, map(hash, self.behaviors.keys()), 0) ^
+            hash(self.binding)
+        )
 
     def __nonzero__(self):
         return bool(self.value)
@@ -76,18 +84,50 @@ class Object(object):
     def __setitem__(self, key, value):
         self.attrs[key] = value
 
-    def __addtrait__(self, trait):
-        attrs = ((k, v) for k, v in trait.attrs.items())
-        methods = ((k, v) for k, v in attrs if v.type == "Block")
-        behaviors = ((k, v) for k, v in methods if not k in self.attrs)
+    def __addtrait__(self, trait, **resolution):
+        from .trait import Trait
 
-        self.behaviors.update(behaviors)
-        self.traits.append(trait)
+        if not isinstance(trait, Trait):
+            raise TypeError("Trait expected but got {0:s}".format(repr(getattr(trait, "type", trait.__class__.__name__))))
+
+        for requirement in trait.requirements:
+            if not self.lookup(requirement):
+                raise TypeError("{0:s} requires {0:s}".format(repr(trait), repr(requirement)))
+
+        for k, v in trait.attrs.items():
+            if k in self:
+                name = resolution.get(k, None)
+                if not name:
+                    raise TypeError("Method {0:s} of 1:s} conflicts with {2:s}".format(k, repr(trait), repr(self)))
+                else:
+                    self.behaviors[name] = v
+            else:
+                self.behaviors[k] = v
+
+        self.traits[trait] = resolution
 
     def __deltrait__(self, trait):
+        resolution = self.traits[trait]
+
         for k, v in trait.attrs.items():
-            del self.behaviors[k]
-        self.traits.remove(trait)
+            if k in self.behaviors:
+                del self.behaviors[k]
+            else:
+                del self.behaviors[resolution[k]]
+
+        del self.traits[trait]
+
+    def __hastrait__(self, trait):
+        if trait in self.traits:
+            return True
+
+        parent = self.parent
+        while parent is not None:
+            if trait in parent.traits:
+                return True
+            parent = parent.parent
+
+        return False
 
     def __repr__(self):
         type = "{0:s}({1:s})".format(self.binding, self.type) if self.binding is not None else self.type
@@ -108,7 +148,7 @@ class Object(object):
         obj.parent = self
         obj.value = value if value is not Null else obj.value
 
-        obj.traits = []
+        obj.traits = {}
         obj.behaviors = {}
 
         self.binding = None
@@ -130,7 +170,7 @@ class Object(object):
 
     @method("del")
     def _del(self, receiver, context, m, key):
-        key = str(key.eval(context))
+        key = unicode(key.eval(context))
         value = receiver[key]
         del receiver[key]
         if isinstance(value, Object):
@@ -139,14 +179,14 @@ class Object(object):
 
     @method()
     def has(self, receiver, context, m, key):
-        key = str(key.eval(context))
+        key = unicode(key.eval(context))
         if key in receiver:
             return runtime.find("True")
         return runtime.find("False")
 
     @method()
     def set(self, receiver, context, m, key, value):
-        key = str(key.eval(context))
+        key = unicode(key.eval(context))
         value = value.eval(context)
         if isinstance(value, Object):
             value.binding = key
@@ -155,40 +195,44 @@ class Object(object):
 
     @method()
     def get(self, receiver, context, m, key, default=None):
-        key = str(key.eval(context))
+        key = unicode(key.eval(context))
         default = default.eval(context) if default else runtime.find("None")
         return receiver.attrs.get(key, default)
 
     # Traits Operations
 
     @method()
-    def uses(self, receiver, context, m, *traits):
-        traits = [trait.eval(context) for trait in traits]
-        for trait in traits:
-            receiver.__addtrait__(trait)
-        return receiver
-
-    @method()
-    def addTrait(self, receiver, context, m, trait):
+    def use(self, receiver, context, m, trait, resolution=None):
         trait = trait.eval(context)
-        receiver.__addtrait__(trait)
+
+        if receiver.__hastrait__(trait):
+            raise TypeError("{0:s} already uses 1:s}".format(repr(receiver), repr(trait)))
+
+        resolution = runtime.state.frommio(resolution.eval(context)) if resolution is not None else {}
+
+        receiver.__addtrait__(trait, **resolution)
+
         return receiver
 
     @method()
     def delTrait(self, receiver, context, m, trait):
         trait = trait.eval(context)
+
+        if not receiver.__hastrait__(trait):
+            raise TypeError("{0:s} does not use {1:s}".format(repr(receiver), repr(trait)))
+
         receiver.__deltrait__(trait)
+
         return receiver
 
     @method()
     def hasTrait(self, receiver, context, m, trait):
         trait = trait.eval(context)
-        test = trait in receiver.traits
-        return runtime.find("True") if test else runtime.find("False")
+        return runtime.find("True") if receiver.__hastrait__(trait) else runtime.find("False")
 
     @method("traits", True)
     def getTraits(self, receiver, context, m):
-        return runtime.find("List").clone(receiver.traits)
+        return runtime.find("List").clone(receiver.traits.keys())
 
     @method("behaviors", True)
     def getBehaviors(self, receiver, context, m):
@@ -265,9 +309,13 @@ class Object(object):
 
     # Object Operations
 
+    @method()
+    def init(self, receiver, context, m):
+        return receiver
+
     @method()
     def primitive(self, receiver, context, m, method, *args):
-        method = str(method.eval(context))
+        method = unicode(method.eval(context))
         args = [arg.eval(context).value for arg in args]
         if hasattr(receiver, method):
             return getattr(receiver, method)(*args)
@@ -314,4 +362,4 @@ class Object(object):
 
     @method("__str__")
     def getStr(self, receiver, context, m):
-        return runtime.find("String").clone(str(receiver))
+        return runtime.find("String").clone(unicode(receiver))
