@@ -60,7 +60,7 @@ def make_message(n):
 
     if next is not None:
         message = Message(name, value)
-        message.next = Message(next, next, args)
+        message.next = Message(next, None, args)
     else:
         message = Message(name, value, args)
 
@@ -146,14 +146,23 @@ def make_number(n):
 
 
 def make_string(n):
+    if n and n[0] in "bu":
+        prefix = n[0]
+        n = n[1:]
+    else:
+        prefix = "u"
+
     if len(n) > 3 and (n[:3] in ("'''", '"""')):
         n = n[3:-3]
     else:
         n = n[1:-1]
 
-    s = n.decode("string-escape")
+    if prefix == "u":
+        s = n.decode("unicode-escape")
+    else:
+        s = n.decode("string-escape")
 
-    return runtime.find("String").clone(s)
+    return runtime.find("String" if prefix == "u" else "Bytes").clone(s)
 
 
 def make_terminator(n):
