@@ -7,41 +7,6 @@ from .errors import Error
 from .version import version
 
 
-def fromDict(x):
-    return dict(x.value)
-
-
-def fromBoolean(x):
-    if x.value is None:
-        return None
-    return bool(x.value)
-
-
-def toBoolean(x):
-    return "True" if x else "False"
-
-
-typemap = {
-    "tomio": {
-        dict:       "Dict",
-        list:       "List",
-        str:        "String",
-        bool:       toBoolean,
-        int:        "Number",
-        type(None): "None",
-        float:      "Number",
-        Decimal:    "Number",
-    },
-    "frommio": {
-        "Dict":    fromDict,
-        "List":    list,
-        "String":  str,
-        "Boolean": fromBoolean,
-        "Number":  float
-    }
-}
-
-
 def check_parens(s):
     return s.count("(") == s.count(")")
 
@@ -54,6 +19,57 @@ class State(object):
         self.args = args if args is not None else []
         self.opts = opts
 
+        self.typemap = {
+            "tomio": {
+                dict:       self.toDict,
+                list:       self.toList,
+                tuple:      self.toTuple,
+                bool:       self.toBoolean,
+                str:        "Bytes",
+                bytes:      "Bytes",
+                unicode:    "String",
+                int:        "Number",
+                type(None): "None",
+                float:      "Number",
+                Decimal:    "Number",
+            },
+            "frommio": {
+                "Dict":    self.fromDict,
+                "List":    self.fromList,
+                "Tuple":   self.fromTuple,
+                "Boolean": self.fromBoolean,
+                "Bytes":   bytes,
+                "String":  unicode,
+                "Number":  float
+            }
+        }
+
+    def fromDict(self, x):
+        return dict((self.frommio(k), self.frommio(v)) for k, v in x.value.items())
+
+    def fromList(self, xs):
+        return list(self.frommio(x) for x in xs.value)
+
+    def fromTuple(self, xs):
+        return tuple(self.frommio(x) for x in xs.value)
+
+    def fromBoolean(self, x):
+        if x.value is None:
+            return None
+        return bool(x.value)
+
+    def toDict(self, x):
+        return self.find("Dict").clone(dict(((self.tomio(k), self.tomio(v)) for k, v in x.items())))
+
+    def toList(self, xs):
+        return self.find("List").clone(list((self.tomio(x) for x in xs)))
+
+    def toTuple(self, xs):
+        return self.find("Tuple").clone(tuple((self.tomio(x) for x in xs)))
+
+    def toBoolean(self, x):
+        return self.find("True") if x else self.find("False")
+
     @property
     def value(self):
         return self._value
@@ -64,6 +80,7 @@ class State(object):
 
     def bootstrap(self):
         from .object import Object
+        from .trait import Trait
 
         # Fake Object to solve chicken/egg problem.
         self.root = {"Object": None}
@@ -74,6 +91,7 @@ class State(object):
         root.parent = object
 
         root["Object"] = object
+        root["Trait"] = Trait()
         root["Root"] = root
 
         self.root = root
@@ -81,11 +99,13 @@ class State(object):
     def initialize(self):
         from .core import Core
         from .types import Types
+        from .traits import Traits
 
         root = self.root
 
         root["Types"] = Types()
         root["Core"] = Core()
+        root["Traits"] = Traits()
 
         # Bootstrap the system
         if self.opts is None or (self.opts is not None and not self.opts.nosys):
@@ -95,22 +115,27 @@ class State(object):
         del self.root["_"]
 
     def frommio(self, x, default=None):
-        return typemap["frommio"].get(x.type, lambda x: default)(x)
+        return self.typemap["frommio"].get(x.type, lambda x: default)(x)
 
     def tomio(self, x, default="None"):
-        mapto = typemap["tomio"].get(type(x), default)
+        mapto = self.typemap["tomio"].get(type(x), default)
 
-        try:
-            obj = self.find(mapto(x)) if callable(mapto) else self.find(mapto)
-            return obj.clone(x)
-        except:
-            return default
+        if callable(mapto):
+            return mapto(x)
+        else:
+            try:
+                obj = self.find(mapto(x)) if callable(mapto) else self.find(mapto)
+                return obj.clone(x)
+            except KeyError:
+                return default
 
     def find(self, name):
         if "Types" in self.root and name in self.root["Types"]:
             return self.root["Types"][name]
         elif "Core" in self.root and name in self.root["Core"]:
             return self.root["Core"][name]
+        elif "Traits" in self.root and name in self.root["Traits"]:
+            return self.root["Traits"][name]
         elif "builtins" in self.root and name in self.root["builtins"]:
             return self.root["builtins"][name]
         else:
