@@ -2,7 +2,6 @@ from pytest import raises
 
 
 from mio import runtime
-from mio.utils import format_object
 from mio.errors import AttributeError, TypeError
 
 
@@ -76,7 +75,7 @@ def test_has2(mio):
 
 
 def test_hash(mio):
-    assert mio.eval("Object hash") == hash(runtime.find("Object"))
+    assert mio.eval("Object __hash__()") == hash(runtime.find("Object"))
 
 
 def test_id(mio):
@@ -124,15 +123,6 @@ def test_del(mio):
         mio.eval("Foo count", reraise=True)
 
 
-def test_summary(mio, capfd):
-    mio.eval("Foo = Object clone()")
-    assert mio.eval("Foo x = 1")
-
-    assert mio.eval("Foo summary") == mio.eval("Foo")
-    out, err = capfd.readouterr()
-    assert out == "{0:s}\n".format(format_object(mio.eval("Foo")))
-
-
 def test_print(mio, capfd):
     assert mio.eval("print(\"Hello World!\")").value is None
     out, err = capfd.readouterr()
@@ -153,7 +143,7 @@ def test_print_end(mio, capfd):
 
 def test_repr(mio):
     assert mio.eval("1 __repr__()") == "1"
-    assert mio.eval("\"foo\"__repr__()") == "'foo'"
+    assert mio.eval("\"foo\"__repr__()") == "u\"foo\""
 
 
 def test_str(mio):
