@@ -6,14 +6,14 @@ from mio.errors import AttributeError
 
 def test_basic_trait(mio, capfd):
     mio.eval("""
-        TGreeting = Object clone() do (
+        TGreeting = Trait clone() do (
             hello = method(
                 print("Hello", self getGreeting())
             )
         )
 
         World = Object clone() do (
-            uses(TGreeting)
+            use(TGreeting)
 
             greeting = "World!"
 
@@ -39,9 +39,9 @@ def test_basic_trait(mio, capfd):
 
 def test_hasTrait(mio):
     mio.eval("""
-        TGreetable = Object clone()
+        TGreetable = Trait clone()
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
@@ -50,9 +50,9 @@ def test_hasTrait(mio):
 
 def test_delTrait(mio):
     mio.eval("""
-        TGreetable = Object clone()
+        TGreetable = Trait clone()
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
@@ -64,14 +64,14 @@ def test_delTrait(mio):
 
 def test_delTrait2(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone() do (
+        TGreetable = Trait clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
@@ -90,22 +90,11 @@ def test_delTrait2(mio, capfd):
         mio.eval("World hello()", reraise=True)
 
 
-def test_addTrait(mio):
-    mio.eval("""
-        TGreetable = Object clone()
-        World = Object clone()
-    """)
-
-    assert not mio.eval("World hasTrait(TGreetable)")
-    mio.eval("World addTrait(TGreetable)")
-    assert mio.eval("World hasTrait(TGreetable)")
-
-
 def test_traits(mio):
     mio.eval("""
-        TGreetable = Object clone()
+        TGreetable = Trait clone()
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
@@ -115,14 +104,14 @@ def test_traits(mio):
 
 def test_behaviors(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone() do (
+        TGreetable = Trait clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
@@ -134,14 +123,14 @@ def test_behaviors(mio, capfd):
 
 def test_del_behavior(mio, capfd):
     mio.eval("""
-        TGreetable = Object clone() do (
+        TGreetable = Trait clone() do (
             hello = method(
                 print("Hello World!")
             )
         )
 
         World = Object clone() do (
-            uses(TGreetable)
+            use(TGreetable)
         )
     """)
 
