@@ -43,6 +43,16 @@ def test_at(mio):
     assert mio.eval("xs at(0)") == 1
 
 
+def test_getitem(mio):
+    mio.eval("xs = List clone()")
+    mio.eval("xs append(1)")
+    mio.eval("xs append(2)")
+    mio.eval("xs append(3)")
+    assert mio.eval("xs") == [1, 2, 3]
+
+    assert mio.eval("xs __getitem__(0)") == 1
+
+
 def test_len(mio):
     mio.eval("xs = List clone()")
     mio.eval("xs append(1)")
@@ -53,6 +63,24 @@ def test_len(mio):
     assert mio.eval("xs len") == 3
 
 
+def test_len2(mio):
+    mio.eval("xs = List clone()")
+    mio.eval("xs append(1)")
+    mio.eval("xs append(2)")
+    mio.eval("xs append(3)")
+    assert mio.eval("xs") == [1, 2, 3]
+
+    assert mio.eval("xs __len__()") == 3
+
+
+def test_len3(mio):
+    mio.eval("xs = List clone()")
+    mio.eval("xs append(1)")
+    mio.eval("xs append(2)")
+    mio.eval("xs append(3)")
+    assert len(mio.eval("xs")) == 3
+
+
 def test_count(mio):
     mio.eval("xs = List clone()")
     mio.eval("xs append(1)")
